-- make-up table state machine

beginStateMachine()

	onMsg("buildMenu", function(msg)
	
		if (repairMenu()) then return end
	
		-- build the pie menu
		clearPieMenu();
		local button;
		button = addPieMenuButton("pm_makeHair", "makeHair");
		button.addDescription(ACTIVITY, "makeHair");
		-- button.addIcon("guiIconHygiene");
		
		-- add hairstyles
		-- get character who initiated this action
		local character = getStateObjectFromID(msg.sender);
		if (character) then
			local hairStyles = character.getHairStyles();
			if (table.getn(hairStyles) > 1) then
				local hairStyleButton = addPieMenuButton("pm_changeHairStyle", "");
				for i = 1, table.getn(hairStyles) do
					local hairStyle = hairStyles[i];
					if (hairStyle.getID() ~= character.getHairStyle()) then
						button = hairStyleButton.addPieMenuButton(hairStyle.getName(), "changeHairStyle", hairStyle.getID());
					end
				end
			end
		end
		
		-- add skincolors
		if (character) then
			local skinColors = character.getSkinColors();
			if (table.getn(skinColors) > 1) then
				local skinColorButton = addPieMenuButton("pm_changeSkinColor", "");
				for i = 1, table.getn(skinColors) do
					local skinColor = skinColors[i];
					if (skinColor.getID() ~= character.getSkinColor()) then
						button = skinColorButton.addPieMenuButton(skinColor.getName(), "changeSkinColor", skinColor.getID());
					end
				end
			end
		end
		
		-- add eyecolors
		if (character) then
			local eyeColors = character.getEyeColors();
			if (table.getn(eyeColors) > 1) then
				local eyeColorButton = addPieMenuButton("pm_changeEyeColor", "");
				for i = 1, table.getn(eyeColors) do
					local eyeColor = eyeColors[i];
					if (eyeColor.getID() ~= character.getEyeColor()) then
						button = eyeColorButton.addPieMenuButton(eyeColor.getName(), "changeEyeColor", eyeColor.getID());
					end
				end
			end
		end
	end )

	-- 
	
	onMsg("makeHair", function(msg)
		-- get the game object server
		local gameObjectServer = getGameObjectServer();
		-- get character who initiated this action
		local character = getStateObjectFromID(msg.sender);
		
		-- check if activity is possible
		local possible, result, activity = activityPossible(character, msg.name, this);
		
		-- don't care if timeslot is not fulfilled
		if (possible or (result == TIMESLOT)) then
			-- if this is broken: abort characters action
			if abortIfBroken(character) then return end;
			-- walk to the closest action point
			local actionPoint = character.getFreeActionPoint(this, "change");
			if (actionPoint) then
				-- get the walk state object
				local wso = character.walkSO;
				local wsoContext = StateMachineContext();
				wsoContext.storeData("actionPointName", actionPoint.getName());
				if (wso.walkToActionPoint(actionPoint)) then
					wso.queueStateMachine("tableMakeUpChar.makeHair", this, wsoContext);
				else
					print("no path found");
					instantAbort(character, EMOTICON_NOPATH, "emoThink")
				end
			else
				print("no action point found");
				instantAbort(character, EMOTICON_CANNOT, "emoThink")
			end
		else
			-- activity not possible
			print(msg.name .. " not possible");
			
			local emoticon;
			if (result == NO_CONDITION) then
				emoticon = conditionToEmoticon(activity.getUnfulfilledCondition());
			else
				emoticon = resultToEmoticon(result);
			end
			instantAbort(character, emoticon, "emoThink");
		end
	end )
	
	onMsg("changeHairStyle", function(msg)
		-- get the game object server
		local gameObjectServer = getGameObjectServer();
		-- get character who initiated this action
		local character = getStateObjectFromID(msg.sender);
		
		-- check if activity is possible
		local possible, result, activity = activityPossible(character, msg.name, this);
		
		-- don't care if timeslot is not fulfilled
		if (possible or (result == TIMESLOT)) then
			-- if this is broken: abort characters action
			if abortIfBroken(character) then return end;
			-- walk to the closest action point
			local actionPoint = character.getFreeActionPoint(this, "change");
			if (actionPoint) then
				-- get the walk state object
				local wso = character.walkSO;
				local wsoContext = StateMachineContext();
				wsoContext.storeData("actionPointName", actionPoint.getName());
				if (wso.walkToActionPoint(actionPoint)) then
					wsoContext.storeData("hairStyle", msg.data);
					wso.queueStateMachine("tableMakeUpChar.changeHairStyle", this, wsoContext);
				else
					print("no path found");
					instantAbort(character, EMOTICON_NOPATH, "emoThink")
				end
			else
				print("no action point found");
				instantAbort(character, EMOTICON_CANNOT, "emoThink")
			end
		else
			-- activity not possible
			print(msg.name .. " not possible");
			
			local emoticon;
			if (result == NO_CONDITION) then
				emoticon = conditionToEmoticon(activity.getUnfulfilledCondition());
			else
				emoticon = resultToEmoticon(result);
			end
			instantAbort(character, emoticon, "emoThink");
		end
	end )

	onMsg("changeSkinColor", function(msg)
		-- get the game object server
		local gameObjectServer = getGameObjectServer();
		-- get character who initiated this action
		local character = getStateObjectFromID(msg.sender);
		
		-- check if activity is possible
		local possible, result, activity = activityPossible(character, msg.name, this);
		
		-- don't care if timeslot is not fulfilled
		if (possible or (result == TIMESLOT)) then
			-- if this is broken: abort characters action
			if abortIfBroken(character) then return end;
			-- walk to the closest action point
			local actionPoint = character.getFreeActionPoint(this, "change");
			if (actionPoint) then
				-- get the walk state object
				local wso = character.walkSO;
				local wsoContext = StateMachineContext();
				wsoContext.storeData("actionPointName", actionPoint.getName());
				if (wso.walkToActionPoint(actionPoint)) then
					wsoContext.storeData("skinColor", msg.data);
					wso.queueStateMachine("tableMakeUpChar.changeSkinColor", this, wsoContext);
				else
					print("no path found");
					instantAbort(character, EMOTICON_NOPATH, "emoThink")
				end
			else
				print("no action point found");
				instantAbort(character, EMOTICON_CANNOT, "emoThink")
			end
		else
			-- activity not possible
			print(msg.name .. " not possible");
			
			local emoticon;
			if (result == NO_CONDITION) then
				emoticon = conditionToEmoticon(activity.getUnfulfilledCondition());
			else
				emoticon = resultToEmoticon(result);
			end
			instantAbort(character, emoticon, "emoThink");
		end
	end )

	onMsg("changeEyeColor", function(msg)
		-- get the game object server
		local gameObjectServer = getGameObjectServer();
		-- get character who initiated this action
		local character = getStateObjectFromID(msg.sender);
		
		-- check if activity is possible
		local possible, result, activity = activityPossible(character, msg.name, this);
		
		-- don't care if timeslot is not fulfilled
		if (possible or (result == TIMESLOT)) then
			-- if this is broken: abort characters action
			if abortIfBroken(character) then return end;
			-- walk to the closest action point
			local actionPoint = character.getFreeActionPoint(this, "change");
			if (actionPoint) then
				-- get the walk state object
				local wso = character.walkSO;
				local wsoContext = StateMachineContext();
				wsoContext.storeData("actionPointName", actionPoint.getName());
				if (wso.walkToActionPoint(actionPoint)) then
					wsoContext.storeData("eyeColor", msg.data);
					wso.queueStateMachine("tableMakeUpChar.changeEyeColor", this, wsoContext);
				else
					print("no path found");
					instantAbort(character, EMOTICON_NOPATH, "emoThink")
				end
			else
				print("no action point found");
				instantAbort(character, EMOTICON_CANNOT, "emoThink")
			end
		else
			-- activity not possible
			print(msg.name .. " not possible");
			
			local emoticon;
			if (result == NO_CONDITION) then
				emoticon = conditionToEmoticon(activity.getUnfulfilledCondition());
			else
				emoticon = resultToEmoticon(result);
			end
			instantAbort(character, emoticon, "emoThink");
		end
	end )
	
	-- repair
	onMsg("repair", function(msg)
	
		print("onMsg repair");
		-- get character who initiated this action
		local character = getStateObjectFromID(msg.sender);
		-- walk to the closest action point
		local actionPoint = character.getFreeActionPoint(this, "repair");
		-- get the walk state object
		local wso = character.walkSO;
		if (actionPoint) then
			-- create state machine contexts
			local wsoContext = StateMachineContext();
			-- store the action point
			wsoContext.storeData("actionPointName", actionPoint.getName());
			if (wso.walkToActionPoint(actionPoint)) then
				wso.queueStateMachine("repairChar.repairStart", this, wsoContext);
			else
				print("no path found");
				instantAbort(character, EMOTICON_NOPATH, "emoThink")
			end
		else
			print("no action point found");
			instantAbort(character, EMOTICON_CANNOT, "emoThink")
		end
	end )
			
endStateMachine()
