-- makeUpTable character state machine
beginStateMachine()
	
	onEnter(function(msg)

		local makeUpTable = getStateObjectFromID(msg.sender);
		storeStateObject("makeUpTable", makeUpTable);
		
		if (makeUpTable) then
			-- makeUpTable does exist
			local actionPointName = retrieveData("actionPointName");
			if exitIfWrongPosition(getParent(), makeUpTable, actionPointName) then return end;				

			if (getParent().isOneActionPointLocked(makeUpTable)) then
				-- action point is locked
				getParent().setEmoticon(EMOTICON_CANNOT, EMOTICON_DELAY);
				sendMsg("emoThink", getParent().walkSO);
				exitStateMachine();
			else
				getParent().lockActionPoints(makeUpTable);
			end
		else
			-- makeUpTable does not exist anymore
			getParent().setEmoticon(EMOTICON_CANNOT, EMOTICON_DELAY);
			sendMsg("emoThink", getParent().walkSO);
			exitStateMachine();
		end
		
		freeHands(getParent());
				
	end )
	
	onExit(function(msg)
		
		unlockAll("makeUpTable");
		
		getParent().stopAllActivities();		
	end )
	
					
	state("makeHair")
	
		onEnter(function(msg)
			local makeUpTable = retrieveStateObject("makeUpTable");

			local makeHair = getParent().startActivity("makeHair", makeUpTable);
			local length, scale = getActivityLength(makeHair);
			
			sendDelayedMsgThis("complete", length);
			sendDelayedMsgThis("testCancel", CANCEL_POLLING_INTERVAL);
			
			local hairBrush = getParent().loadGameObject("StandardGO", "hairBrush");
			local hairSpray = getParent().loadGameObject("StandardGO", "hairSpray");
			getParent().attachRightObjectHolder(hairBrush);
			getParent().attachLeftObjectHolder(hairSpray);

			sendMsgThis("startLoop");
		end )
	
		onMsg("startLoop", function(msg)
			startAnimation("makeHair");
			sendDelayedMsgThis("brushSound", 600);
			sendDelayedMsgThis("spraySound", 5800);
		end )	
		
		onMsg("brushSound", function(msg)
			getParent().playSound("hairBrush");			
		end )	
		
		onMsg("spraySound", function(msg)
			getParent().playSound("hairSpray");			
		end )	
				

		onMsg("complete", function(msg)
			freeHands(getParent());
			getParent().stopActivity("makeHair", retrieveStateObject("makeUpTable"));
			exitAndGoAway();
		end )	
		
		onMsg("testCancel", function(msg)
			if testCancel() or (not this.getParent().getCurrentActivityGain()) then
				sendMsgThis("complete");
			else
				sendDelayedMsgThis("testCancel", CANCEL_POLLING_INTERVAL);
			end
		end )
		
		onMsg("end", function(msg)
			if testCancel() then
				sendMsgThis("complete");
			else
				sendMsgThis("startLoop");
			end
		end )	
	
	state("changeHairStyle")
	
		onEnter(function(msg)
			local hairStyle = retrieveData("hairStyle")
			getParent().changeHairStyle(hairStyle);
			removeData("hairStyle");
			sendMsgThis("end");
		end )
	
		onMsg("end", function(msg)
			exitAndGoAway();
		end )
	
	state("changeSkinColor")
	
		onEnter(function(msg)
			local skinColor = retrieveData("skinColor")
			getParent().changeSkinColor(skinColor);
			removeData("skinColor");
			sendMsgThis("end");
		end )
	
		onMsg("end", function(msg)
			exitAndGoAway();
		end )
		
	state("changeEyeColor")
	
		onEnter(function(msg)
			local eyeColor = retrieveData("eyeColor")
			getParent().changeEyeColor(eyeColor);
			removeData("eyeColor");
			sendMsgThis("end");			
		end )
	
		onMsg("end", function(msg)
			exitAndGoAway();
		end )
		
endStateMachine()
